==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkHyperTreeGrid.java <==
// java wrapper for vtkHyperTreeGrid object
//

package vtk;
import vtk.*;

public class vtkHyperTreeGrid extends vtkDataSet
{

  private native long LEVELS_0();
  public vtkInformationIntegerKey LEVELS() {
    long temp = LEVELS_0();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long DIMENSION_1();
  public vtkInformationIntegerKey DIMENSION() {
    long temp = DIMENSION_1();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long SIZES_2();
  public vtkInformationDoubleVectorKey SIZES() {
    long temp = SIZES_2();

    if (temp == 0) return null;
    return (vtkInformationDoubleVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native String GetClassName_3();
  public String GetClassName()
    { return GetClassName_3(); }

  private native int IsA_4(String id0);
  public int IsA(String id0)
    { return IsA_4(id0); }

  private native int GetDataObjectType_5();
  public int GetDataObjectType()
    { return GetDataObjectType_5(); }

  private native void CopyStructure_6(vtkDataSet id0);
  public void CopyStructure(vtkDataSet id0)
    { CopyStructure_6(id0); }

  private native void SetGridSize_7(int id0,int id1,int id2);
  public void SetGridSize(int id0,int id1,int id2)
    { SetGridSize_7(id0,id1,id2); }

  private native void SetGridExtent_8(int id0[]);
  public void SetGridExtent(int id0[])
    { SetGridExtent_8(id0); }

  private native void SetGridExtent_9(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetGridExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetGridExtent_9(id0,id1,id2,id3,id4,id5); }

  private native void SetTransposedRootIndexing_10(boolean id0);
  public void SetTransposedRootIndexing(boolean id0)
    { SetTransposedRootIndexing_10(id0); }

  private native boolean GetTransposedRootIndexing_11();
  public boolean GetTransposedRootIndexing()
    { return GetTransposedRootIndexing_11(); }

  private native void SetIndexingModeToKJI_12();
  public void SetIndexingModeToKJI()
    { SetIndexingModeToKJI_12(); }

  private native void SetIndexingModeToIJK_13();
  public void SetIndexingModeToIJK()
    { SetIndexingModeToIJK_13(); }

  private native void SetBranchFactor_14(int id0);
  public void SetBranchFactor(int id0)
    { SetBranchFactor_14(id0); }

  private native int GetBranchFactor_15();
  public int GetBranchFactor()
    { return GetBranchFactor_15(); }

  private native void SetDimension_16(int id0);
  public void SetDimension(int id0)
    { SetDimension_16(id0); }

  private native int GetDimension_17();
  public int GetDimension()
    { return GetDimension_17(); }

  private native int GetNumberOfCells_18();
  public int GetNumberOfCells()
    { return GetNumberOfCells_18(); }

  private native int GetNumberOfPoints_19();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_19(); }

  private native int GetNumberOfLeaves_20();
  public int GetNumberOfLeaves()
    { return GetNumberOfLeaves_20(); }

  private native int GetNumberOfLevels_21(int id0);
  public int GetNumberOfLevels(int id0)
    { return GetNumberOfLevels_21(id0); }

  private native int GetNumberOfTrees_22();
  public int GetNumberOfTrees()
    { return GetNumberOfTrees_22(); }

  private native void SetXCoordinates_23(vtkDataArray id0);
  public void SetXCoordinates(vtkDataArray id0)
    { SetXCoordinates_23(id0); }

  private native long GetXCoordinates_24();
  public vtkDataArray GetXCoordinates() {
    long temp = GetXCoordinates_24();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetYCoordinates_25(vtkDataArray id0);
  public void SetYCoordinates(vtkDataArray id0)
    { SetYCoordinates_25(id0); }

  private native long GetYCoordinates_26();
  public vtkDataArray GetYCoordinates() {
    long temp = GetYCoordinates_26();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetZCoordinates_27(vtkDataArray id0);
  public void SetZCoordinates(vtkDataArray id0)
    { SetZCoordinates_27(id0); }

  private native long GetZCoordinates_28();
  public vtkDataArray GetZCoordinates() {
    long temp = GetZCoordinates_28();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetMaterialMask_29(vtkBitArray id0);
  public void SetMaterialMask(vtkBitArray id0)
    { SetMaterialMask_29(id0); }

  private native long GetMaterialMask_30();
  public vtkBitArray GetMaterialMask() {
    long temp = GetMaterialMask_30();

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetMaterialMaskIndex_31(vtkIdTypeArray id0);
  public void SetMaterialMaskIndex(vtkIdTypeArray id0)
    { SetMaterialMaskIndex_31(id0); }

  private native long GetMaterialMaskIndex_32();
  public vtkIdTypeArray GetMaterialMaskIndex() {
    long temp = GetMaterialMaskIndex_32();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void GenerateTrees_33();
  public void GenerateTrees()
    { GenerateTrees_33(); }

  private native long NewCursor_34(int id0);
  public vtkHyperTreeCursor NewCursor(int id0) {
    long temp = NewCursor_34(id0);

    if (temp == 0) return null;
    return (vtkHyperTreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SubdivideLeaf_35(vtkHyperTreeCursor id0,int id1);
  public void SubdivideLeaf(vtkHyperTreeCursor id0,int id1)
    { SubdivideLeaf_35(id0,id1); }

  private native void GetPoint_36(int id0,double id1[]);
  public void GetPoint(int id0,double id1[])
    { GetPoint_36(id0,id1); }

  private native long GetCell_37(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_37(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void GetCell_38(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_38(id0,id1); }

  private native int GetCellType_39(int id0);
  public int GetCellType(int id0)
    { return GetCellType_39(id0); }

  private native void GetCellPoints_40(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_40(id0,id1); }

  private native void GetPointCells_41(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_41(id0,id1); }

  private native void GetCellNeighbors_42(int id0,vtkIdList id1,vtkIdList id2);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2)
    { GetCellNeighbors_42(id0,id1,id2); }

  private native int FindPoint_43(double id0[]);
  public int FindPoint(double id0[])
    { return FindPoint_43(id0); }

  private native void Initialize_44();
  public void Initialize()
    { Initialize_44(); }

  private native int GetMaxCellSize_45();
  public int GetMaxCellSize()
    { return GetMaxCellSize_45(); }

  private native void ShallowCopy_46(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_46(id0); }

  private native void DeepCopy_47(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_47(id0); }

  private native int GetExtentType_48();
  public int GetExtentType()
    { return GetExtentType_48(); }

  private native int GetActualMemorySize_49();
  public int GetActualMemorySize()
    { return GetActualMemorySize_49(); }

  private native void GenerateSuperCursorTraversalTable_50();
  public void GenerateSuperCursorTraversalTable()
    { GenerateSuperCursorTraversalTable_50(); }

  private native int GetNumberOfChildren_51();
  public int GetNumberOfChildren()
    { return GetNumberOfChildren_51(); }

  public vtkHyperTreeGrid() { super(); }

  public vtkHyperTreeGrid(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkHyperTreeGrid.java <==
// java wrapper for vtkHyperTreeGrid object
//

package vtk;
import vtk.*;

public class vtkHyperTreeGrid extends vtkDataSet
{

  private native long LEVELS_0();
  public vtkInformationIntegerKey LEVELS() {
    long temp = LEVELS_0();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long DIMENSION_1();
  public vtkInformationIntegerKey DIMENSION() {
    long temp = DIMENSION_1();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long SIZES_2();
  public vtkInformationDoubleVectorKey SIZES() {
    long temp = SIZES_2();

    if (temp == 0) return null;
    return (vtkInformationDoubleVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int IsTypeOf_3(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_3(id0); }

  private native int IsA_4(String id0);
  public int IsA(String id0)
    { return IsA_4(id0); }

  private native int GetDataObjectType_5();
  public int GetDataObjectType()
    { return GetDataObjectType_5(); }

  private native void CopyStructure_6(vtkDataSet id0);
  public void CopyStructure(vtkDataSet id0)
    { CopyStructure_6(id0); }

  private native void SetGridSize_7(int id0,int id1,int id2);
  public void SetGridSize(int id0,int id1,int id2)
    { SetGridSize_7(id0,id1,id2); }

  private native void SetGridExtent_8(int id0[]);
  public void SetGridExtent(int id0[])
    { SetGridExtent_8(id0); }

  private native void SetGridExtent_9(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetGridExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetGridExtent_9(id0,id1,id2,id3,id4,id5); }

  private native void SetTransposedRootIndexing_10(boolean id0);
  public void SetTransposedRootIndexing(boolean id0)
    { SetTransposedRootIndexing_10(id0); }

  private native boolean GetTransposedRootIndexing_11();
  public boolean GetTransposedRootIndexing()
    { return GetTransposedRootIndexing_11(); }

  private native void SetIndexingModeToKJI_12();
  public void SetIndexingModeToKJI()
    { SetIndexingModeToKJI_12(); }

  private native void SetIndexingModeToIJK_13();
  public void SetIndexingModeToIJK()
    { SetIndexingModeToIJK_13(); }

  private native void SetBranchFactor_14(int id0);
  public void SetBranchFactor(int id0)
    { SetBranchFactor_14(id0); }

  private native int GetBranchFactor_15();
  public int GetBranchFactor()
    { return GetBranchFactor_15(); }

  private native void SetDimension_16(int id0);
  public void SetDimension(int id0)
    { SetDimension_16(id0); }

  private native int GetDimension_17();
  public int GetDimension()
    { return GetDimension_17(); }

  private native int GetNumberOfCells_18();
  public int GetNumberOfCells()
    { return GetNumberOfCells_18(); }

  private native int GetNumberOfPoints_19();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_19(); }

  private native int GetNumberOfLeaves_20();
  public int GetNumberOfLeaves()
    { return GetNumberOfLeaves_20(); }

  private native int GetNumberOfLevels_21(int id0);
  public int GetNumberOfLevels(int id0)
    { return GetNumberOfLevels_21(id0); }

  private native int GetNumberOfTrees_22();
  public int GetNumberOfTrees()
    { return GetNumberOfTrees_22(); }

  private native void SetXCoordinates_23(vtkDataArray id0);
  public void SetXCoordinates(vtkDataArray id0)
    { SetXCoordinates_23(id0); }

  private native long GetXCoordinates_24();
  public vtkDataArray GetXCoordinates() {
    long temp = GetXCoordinates_24();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetYCoordinates_25(vtkDataArray id0);
  public void SetYCoordinates(vtkDataArray id0)
    { SetYCoordinates_25(id0); }

  private native long GetYCoordinates_26();
  public vtkDataArray GetYCoordinates() {
    long temp = GetYCoordinates_26();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetZCoordinates_27(vtkDataArray id0);
  public void SetZCoordinates(vtkDataArray id0)
    { SetZCoordinates_27(id0); }

  private native long GetZCoordinates_28();
  public vtkDataArray GetZCoordinates() {
    long temp = GetZCoordinates_28();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMaterialMask_29(vtkBitArray id0);
  public void SetMaterialMask(vtkBitArray id0)
    { SetMaterialMask_29(id0); }

  private native long GetMaterialMask_30();
  public vtkBitArray GetMaterialMask() {
    long temp = GetMaterialMask_30();

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMaterialMaskIndex_31(vtkIdTypeArray id0);
  public void SetMaterialMaskIndex(vtkIdTypeArray id0)
    { SetMaterialMaskIndex_31(id0); }

  private native long GetMaterialMaskIndex_32();
  public vtkIdTypeArray GetMaterialMaskIndex() {
    long temp = GetMaterialMaskIndex_32();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GenerateTrees_33();
  public void GenerateTrees()
    { GenerateTrees_33(); }

  private native long NewCursor_34(int id0);
  public vtkHyperTreeCursor NewCursor(int id0) {
    long temp = NewCursor_34(id0);

    if (temp == 0) return null;
    return (vtkHyperTreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SubdivideLeaf_35(vtkHyperTreeCursor id0,int id1);
  public void SubdivideLeaf(vtkHyperTreeCursor id0,int id1)
    { SubdivideLeaf_35(id0,id1); }

  private native void GetPoint_36(int id0,double id1[]);
  public void GetPoint(int id0,double id1[])
    { GetPoint_36(id0,id1); }

  private native long GetCell_37(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_37(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetCell_38(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_38(id0,id1); }

  private native int GetCellType_39(int id0);
  public int GetCellType(int id0)
    { return GetCellType_39(id0); }

  private native void GetCellPoints_40(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_40(id0,id1); }

  private native void GetPointCells_41(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_41(id0,id1); }

  private native void GetCellNeighbors_42(int id0,vtkIdList id1,vtkIdList id2);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2)
    { GetCellNeighbors_42(id0,id1,id2); }

  private native int FindPoint_43(double id0[]);
  public int FindPoint(double id0[])
    { return FindPoint_43(id0); }

  private native void Initialize_44();
  public void Initialize()
    { Initialize_44(); }

  private native int GetMaxCellSize_45();
  public int GetMaxCellSize()
    { return GetMaxCellSize_45(); }

  private native void ShallowCopy_46(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_46(id0); }

  private native void DeepCopy_47(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_47(id0); }

  private native int GetExtentType_48();
  public int GetExtentType()
    { return GetExtentType_48(); }

  private native int GetActualMemorySize_49();
  public int GetActualMemorySize()
    { return GetActualMemorySize_49(); }

  private native void GenerateSuperCursorTraversalTable_50();
  public void GenerateSuperCursorTraversalTable()
    { GenerateSuperCursorTraversalTable_50(); }

  private native int GetNumberOfChildren_51();
  public int GetNumberOfChildren()
    { return GetNumberOfChildren_51(); }

  private native long GetCell_52(int id0,int id1,int id2);
  public vtkCell GetCell(int id0,int id1,int id2) {
    long temp = GetCell_52(id0,id1,id2);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkHyperTreeGrid() { super(); }

  public vtkHyperTreeGrid(long id) { super(id); }
  public native long   VTKInit();

}
